@@ -23,14 +23,17 @@
 
 class LogObject {
 	var $text;
+	var $connectionId;
 	var $database;
 	var $user;
 	var $timestamp;
 	var $commandNumber = 0;
 	var $ignored;
 	var $context;
+	var $notices = array();
 
-	function LogObject($user, $database, $text = '', $ignored = false) {
+	function LogObject($connectionId, $user, $database, $text = '', $ignored = false) {
+		$this->connectionId = $connectionId;
 		$this->user = $user;
 		$this->database = $database;
 		$this->text = $text;
@@ -59,6 +62,14 @@ class LogObject {
 		$this->text .= ' '.$text;
 	}
 	
+	function addNotice($notice) {
+		$this->notices[] = $notice;
+	}
+	
+	function getNotices() {
+		return $this->notices;
+	}
+	
 	function setContext($context) {
 		$this->context = normalizeWhitespaces($context);
 	}
@@ -95,6 +106,10 @@ class LogObject {
 		return $this->ignored;
 	}
 	
+	function getConnectionId() {
+		return $this->connectionId;
+	}
+	
 	function getDatabase() {
 		return $this->database;
 	}
