@@ -27,6 +27,11 @@ define('MAX_TIMESTAMP', 9999999999);
 define('EVENT_QUERY', 'query_event_type');
 define('EVENT_ERROR', 'error_event_type');
 define('EVENT_DURATION_ONLY', 'duration_only_event_type');
+define('EVENT_VACUUM_TABLE', 'vacuum_table');
+define('EVENT_ANALYZE_TABLE', 'analyze_table');
+define('EVENT_FSM_INFORMATION', 'fsm_information');
+
+define('UNKNOWN_DATABASE', 'unknown');
 
 function debug($string, $displayLineNumber = false) {
 	stderr($string, $displayLineNumber);
@@ -74,6 +79,15 @@ function formatTimestamp($timestamp) {
 	return date('Y-m-d H:i:s', $timestamp);
 }
 
+function getExactPercentage($number, $total) {
+	if($total > 0) {
+		$percentage = $number*100/$total;
+	} else {
+		$percentage = 0;
+	}
+	return $percentage;
+}
+
 function normalizeWhitespaces($text) {
 	$text = trim($text);
 	$text = preg_replace('/\s+/', ' ', $text);
@@ -162,6 +176,10 @@ class RegExpMatch {
 		$postMatch = substr($this->text, $this->matches[0][1] + strlen($this->matches[0][0]));
 		return $postMatch;
 	}
+	
+	function getMatchCount() {
+		return count($this->matches);
+	}
 }
 
 class QueryCounter {
