@@ -22,8 +22,6 @@
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-define('VERSION', '0.6');
-
 ini_set('max_execution_time', 18000);
 
 if(strpos(phpversion(), '4.4') === 0) {
@@ -32,6 +30,7 @@ if(strpos(phpversion(), '4.4') === 0) {
 	error_reporting(E_ALL);
 }
 
+include('version.php');
 require_once('include/lib/common.lib.php');
 require_once('include/base.lib.php');
 require_once('include/listeners/listeners.lib.php');
@@ -43,8 +42,8 @@ $stderr = fopen('php://stderr', 'w');
 function usage($error = false) {
 	if($error) {
 		stderr('Error: '.$error);
+		echo "\n";
 	}
-	echo "\n";
 	echo 'Usage: '.$GLOBALS['executable'].' -file <file> [-top <n>] [-format <format>] [-logtype <logtype>] [-report [outputfile=]<block1,block2>]
   -file <file>                           log file to analyze
   -                                      read the log from stdin instead of -file
@@ -54,7 +53,8 @@ function usage($error = false) {
                                           for stderr, you have to use the following log_line_prefix: \'%t [%p]: [%l-1] \'
   -report [outputfile=]<block1,block2>   list of report blocks separated by a comma
                                          report blocks can be: overall, hourly, bytype, slowest, n-mosttime,
-                                          n-mostfrequent, n-slowestaverage, n-mostfrequenterrors
+                                          n-mostfrequent, n-slowestaverage, history, n-mostfrequenterrors,
+                                          tsung
                                          you can add several -report options if you want to generate several reports at once
   -examples <n>                          maximum number of examples for a normalized query
   -onlyselect                            ignore all queries but SELECT
@@ -100,7 +100,15 @@ function checkOutputFilePath($filePath) {
 	}
 }
 
-$executable = array_shift($argv);
+if(isset($_SERVER['argv']) && (!isset($argv) || empty($argv))) {
+	$argv = $_SERVER['argv'];
+}
+if(is_array($argv)) {
+	$executable = array_shift($argv);
+} else {
+	$argv = array();
+	$executable = 'unknown';
+}
 
 $options = array();
 $argvCount = count($argv);
@@ -155,6 +163,8 @@ if(isset($options['profile'])) {
 	define('PROFILE', 0);
 }
 
+define('CONFIG_FILTER', false);
+
 if(!CONFIG_STDIN) {
 	if(!isset($options['file'])) {
 		usage('the -file option is required');
@@ -189,13 +199,15 @@ define('CONFIG_TOP_QUERIES_NUMBER', $top);
 $outputToFiles = false;
 $supportedReportBlocks = array(
 	'overall' => 'OverallStatsReport',
-	'hourly' => 'HourlyStatsReport',
 	'bytype' => 'QueriesByTypeReport',
+	'hourly' => 'HourlyStatsReport',
 	'slowest' => 'SlowestQueriesReport',
 	'n-mosttime' => 'NormalizedQueriesMostTimeReport',
 	'n-mostfrequent' => 'NormalizedQueriesMostFrequentReport',
 	'n-slowestaverage' => 'NormalizedQueriesSlowestAverageReport',
+	'history' => 'QueriesHistoryReport',
 	'n-mostfrequenterrors' => 'NormalizedErrorsMostFrequentReport',
+	'tsung' => 'TsungSessionsReport',
 );
 $defaultReportBlocks = array('overall', 'bytype', 'slowest', 'n-mosttime', 'n-mostfrequent', 'n-slowestaverage');
 
@@ -205,13 +217,25 @@ if(isset($options['reports'])) {
 		if(strpos($report, '=') !== false) {
 			list($outputFilePath, $blocks) = explode('=', $report);
 			$outputToFiles = true;
+		} elseif(strpos($report, '.') !== false) {
+			$outputFilePath = $report;
+			$blocks = 'default';
+			$outputToFiles = true;
 		} else {
 			$outputFilePath = false;
 			$blocks = $report;
 			$outputToFiles = false;
 		}
-		$selectedBlocks = explode(',', $blocks);
-		$notSupportedBlocks = array_diff($selectedBlocks, array_keys($supportedReportBlocks));
+		if($blocks == 'default') {
+			$selectedBlocks = $defaultReportBlocks;
+			$notSupportedBlocks = array();
+		} elseif($blocks == 'all') {
+			$selectedBlocks = array_keys($supportedReportBlocks);
+			$notSupportedBlocks = array();
+		} else {
+			$selectedBlocks = explode(',', $blocks);
+			$notSupportedBlocks = array_diff($selectedBlocks, array_keys($supportedReportBlocks));
+		}
 		
 		if(empty($notSupportedBlocks)) {
 			$outputFilePath = checkOutputFilePath($outputFilePath);
